# Salesforce Applications Modeling Best Practices
### On this page
  * [Salesforce (SaaS)](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices#salesforce-\(saas\))
  * [Salesforce (PaaS)](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices#salesforce-\(paas\))


This modeling guide offers best practices for modeling Salesforce as a SaaS and a PaaS solution.
Similar to SAP, Salesforce is heavily used worldwide as the leading CRM tool. In contrast to the SAP solutions we analyzed in the previous sections, Salesforce can be considered a SaaS and a PaaS solution. The modeling is different. In the following sections, we will show you best practices for modeling Salesforce as a SaaS and a PaaS solution.
